/*
 * This file is part of DesktopBSD, see the README file.
 *
 * Author: Peter Hofer <hofer.p@gmail.com>
 *         (C) 2004, 2005
 *
 * Copyright: BSD, see the COPYING file included in this distribution
 *
 */

#ifndef __FRMPKGUPGRADECONTROLLER_H
#define __FRMPKGUPGRADECONTROLLER_H

#include "uifrmpkgupgradecontroller.h"

#include <kparts/part.h>
#include <qpixmap.h>

class KProcess;
class QStrList;
class ExtTerminalInterface;
class PkgUpgradeController;

class FrmPkgUpgradeController : public uiFrmPkgUpgradeController
{
  Q_OBJECT

public:
	FrmPkgUpgradeController(QWidget* parent = 0, const char* name = 0, WFlags fl = 0 );

	void setCommand(QStringList args);
	void setCommand(const QString & program, QStrList args);
	virtual void polish();

protected slots:
	virtual void progressMessage(const QString &);
	virtual void warningMessage(const QString &);
	virtual void informationMessage(const QString &);

	virtual void operationProgressChanged(int percent);
	virtual void moveBusyIndicator();

	virtual void processExited(KProcess *);

protected:
	enum MessageType {
		None,
		Progress,
		Warning,
		Information
	};

	void message(MessageType, const QString &);

	virtual void closeEvent(QCloseEvent *);

private:
	QString commandString;
	QStrList commandArguments;

	QTimer* busyIndicatorTimer;
	void enableBusyIndicatorTimer(bool);

	KParts::Part *terminalPart;
	ExtTerminalInterface *terminalInterface;

	PkgUpgradeController *controller;

	int currentMessageType;
	QPixmap pmProgress, pmWarning, pmInfo, pmNone, pmClose;

	bool finished;
	bool canceled;
};

#endif /* __FRMPKGUPGRADECONTROLLER_H */
